# Define global variables
$current_dir = File.expand_path(File.dirname(__FILE__))
$base_dir = File.expand_path(File.dirname(__FILE__) + '/../..')

require "#{$current_dir}/project_env.rb"
require 'mail'
require 'capybara'
require 'capybara/cucumber'
require 'test/unit'
require 'test/unit/assertions'
require 'action_mailer'
require 'rubygems'
require 'anhpham'
Mail.defaults do
  delivery_method :smtp, {
                           :enable_starttls_auto => true,
                           :address => $SEND_EMAIL_ADDRESS,
                           :port => $SEND_EMAIL_PORT,
                           :domain => $SEND_EMAIL_DOMAIN,
                           :authentication => :plain,
                           :user_name => $SEND_EMAIL_USERNAME,
                           :password => $SEND_EMAIL_PASSWORD
                       }
  retriever_method :pop3, {
                            :address => $RECEIVE_EMAIL_ADDRESS,
                            :port => $RECEIVE_EMAIL_PORT,
                            :user_name => $RECEIVE_EMAIL_USERNAME,
                            :password => $RECEIVE_EMAIL_PASSWORD,
                            :enable_ssl => true
                        }
end

if ENV["SELENIUM"] == 'remote'
  Capybara.app_host = $_CFWEB['Page Address']
  Capybara.default_wait_time = $_CFWEB['Wait Time']
  Capybara.default_driver = :selenium
  Capybara.register_driver :selenium do |app|
    if $_CFWEB['Default Browser'] == :firefox
      profile = Selenium::WebDriver::Firefox::Profile.new
      profile['browser.download.dir'] = $_CFWEB['Download Dir']
      profile['browser.download.folderList'] = 2
      profile['browser.helperApps.neverAsk.saveToDisk'] = "text/csv,application/pdf"
      capabilities = Selenium::WebDriver::Remote::Capabilities.firefox(:firefox_profile => profile)
      Capybara::Selenium::Driver.new(app,
                                     :browser => :remote,
                                     :url => $selenium_grid_url,
                                     :desired_capabilities => capabilities)
    elsif $_CFWEB['Default Browser'] == :internet_explorer
      capabilities = Selenium::WebDriver::Remote::Capabilities.internet_explorer
      Capybara::Selenium::Driver.new(app,
                                     :browser => :remote,
                                     :url => $selenium_grid_url,
                                     :desired_capabilities => capabilities)
    elsif $_CFWEB['Default Browser'] == :chrome
      prefs = {:download => {:prompt_for_download => false, :default_directory => $_CFWEB['Download Dir']}}
      capabilities = Selenium::WebDriver::Remote::Capabilities.chrome
      capabilities['chromeOptions'] = {'prefs' => prefs}
      Capybara::Selenium::Driver.new(app, :browser => :remote,
                                     :url => $selenium_grid_url,
                                     :desired_capabilities => capabilities)
    else
      puts("Not support browser...")
    end
  end
else
  ENV["SELENIUM"] == 'local'
  Capybara.configure do |config|
    config.app_host = $_CFWEB['Page Address']
    config.default_wait_time = $_CFWEB['Wait Time']
    config.run_server = false
    config.default_driver = :selenium
    config.default_selector = :css
    config.ignore_hidden_elements = true
    #config.visible_text_only = true
  end
  Capybara.register_driver :selenium do |app|
    if $_CFWEB['Default Browser'] == :firefox
      profile = Selenium::WebDriver::Firefox::Profile.new
      profile['browser.download.folderList'] = 2
      profile['browser.download.dir'] = $_CFWEB['Download Dir']
      profile['browser.helperApps.neverAsk.saveToDisk'] = "text/csv,application/pdf,application/x-pdf,application/octet-stream"
      profile["pdfjs.disabled"] = true
      Capybara::Selenium::Driver.new(app, :browser => :firefox, :profile => profile)
    elsif $_CFWEB['Default Browser'] == :internet_explorer
      Capybara::Selenium::Driver.new(app, :browser => :internet_explorer)
    elsif $_CFWEB['Default Browser'] == :chrome
      prefs = {:download => {
          :prompt_for_download => false,
          :default_directory => $_CFWEB['Download Dir']
      }}
      args = []
      args << "--test-type" #to fix the error of chrome "you are using an unsupported command-line flag ignore-certificate-errors"

      Capybara::Selenium::Driver.new(app, :browser => :chrome, :prefs => prefs, :args => args)
    else
      puts("Not support browser...")
    end
  end
end
CI_REPORTS = 'features/reports'
World(Test::Unit::Assertions)

